chiark / gitweb /
hash: Trivial whitespace cleanups.
[mLib] / selbuf.c
index 9acc65ff877c61156707121f54531e8d70320302..6fe97eef1c7407af0cb106d4832ed1c25eba2822 100644 (file)
--- a/selbuf.c
+++ b/selbuf.c
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: selbuf.c,v 1.4 2000/06/17 10:38:14 mdw Exp $
+ * $Id: selbuf.c,v 1.6 2004/04/08 01:36:13 mdw Exp $
  *
  * Line-buffering select handler
  *
  * MA 02111-1307, USA.
  */
 
-/*----- Revision history --------------------------------------------------* 
- *
- * $Log: selbuf.c,v $
- * Revision 1.4  2000/06/17 10:38:14  mdw
- * Add support for variable buffer sizes.
- *
- * Revision 1.3  1999/05/22 13:41:00  mdw
- * Fix end-of-file detection and error handling.
- *
- * Revision 1.2  1999/05/17 20:36:50  mdw
- * Make the magical constants for the buffer flags uppercase.
- *
- * Revision 1.1  1999/05/14 21:01:15  mdw
- * Integrated `select' handling bits from the background resolver project.
- *
- */
-
 /*----- Header files ------------------------------------------------------*/
 
 #include <errno.h>
@@ -154,7 +137,7 @@ void selbuf_setsize(selbuf *b, size_t sz)
  * Arguments:  @selbuf *b@ = pointer to buffer block
  *             @sel_state *s@ = pointer to select state to attach to
  *             @int fd@ = file descriptor to listen to
*             @void (*func)(char *s, void *p)@ = function to call
  *             @void *p@ = argument for function
  *
  * Returns:    ---
@@ -162,11 +145,7 @@ void selbuf_setsize(selbuf *b, size_t sz)
  * Use:                Initializes a buffer block.
  */
 
-void selbuf_init(selbuf *b,
-                sel_state *s,
-                int fd,
-                void (*func)(char */*s*/, void */*p*/),
-                void *p)
+void selbuf_init(selbuf *b, sel_state *s, int fd, lbuf_func *func, void *p)
 {
   lbuf_init(&b->b, func, p);
   b->b.f &= ~LBUF_ENABLE;
@@ -154,7 +137,7 @@ void selbuf_setsize(selbuf *b, size_t sz)
  *             @sel_state *s@ = pointer to select state to attach to
  *             @int fd@ = file descriptor to listen to
- *             @void (*func)(char *s, void *p)@ = function to call
+ *             @lbuf_func *func@ = function to call
  *             @void *p@ = argument for function
  *